@@ -1,6 +1,6 @@
 package BankAccount::Validator::UK;
 
-$BankAccount::Validator::UK::VERSION   = '0.33';
+$BankAccount::Validator::UK::VERSION   = '0.34';
 $BankAccount::Validator::UK::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ BankAccount::Validator::UK - Interface to validate UK bank account.
 
 =head1 VERSION
 
-Version 0.33
+Version 0.34
 
 =cut
 
@@ -36,7 +36,7 @@ has sort_code  => (is => 'ro', default => sub { BankAccount::Validator::UK::Rule
 The module uses the algorithm provided by VOCALINK to validate the bank sort code
 and account number.  It is  done by modulus  checking  method as specified in the
 document which is available on their website L<VOCALINK|https://www.vocalink.com/customer-support/modulus-checking>
-It currently supports the document L<v4.60|https://www.vocalink.com/media/2771/vocalink-validating-account-numbers-v460.pdf> dated 8th September 2017.
+It currently supports the document L<v4.70|https://www.vocalink.com/media/2904/vocalink-validating-account-numbers-v47.pdf> dated 13th February 2018.
 
 Institutions covered by this document are below:
 
